# BlueCon

Library for connecting to Fermax Blue supported doorbells.

### Tested Devices:

* Fermax Veo XS WiFi (9449)

## Installation

```sh
pip install bluecon
```

## Acknowledgements

I'd like to thank all contributors of [push_receiver](https://github.com/olijeffers0n/push_receiver) and its many forks for provinding a library that can receive push notifications from Firebase. This is the essencial part of how Fermax Blue works in terms of receiving the doorbell rings and without it this project would be close to pointless. This library is included with some minor changes in this repo.
